searchData={"items":[{"type":"module","title":"HL7","doc":"Struct and functions for parsing and manipulating HL7 messages.\n\nThis library specifically handles version 2.x of HL7 as it is by far the most prevalent format in production.\n\nCheck out [HL7 on Wikipedia](https://en.wikipedia.org/wiki/Health_Level_7) for a decent overview of the format.\n\nSince HL7 messages often lack critical contextual metadata, this struct also contains a `tags` field for metadata support.\n\nUse `new/2` or `new!/2` to convert HL7 text to a parsed HL7 struct.\nThis struct supports the `String.Chars` protocol such that `to_string/1` can be used to format the HL7 message text.\n\nTo see the parsed representation, call `get_segments/1`.\n\nTo query or update HL7 data, use the `sigil_p/2` macro to provide an `HL7.Path` with compile-time guarantees.\nFor dynamic path access, use `HL7.Path.new/1` to construct paths on the fly.\nNote that HL7 path formats have been designed to reflect common industry usage.\n\nThe `get/2`, `put/3`, and `update/4` functions are designed to query and manipulate HL7 data as an HL7 struct (containing a message),\na list of segments, a single segment, a list of repetitions, or a single repetition. These should handle data as\nnested lists (automatically converted to 1-indexed maps), nested sparse maps (1-indexed), simple strings, or mixes of each.\n\nUse `set_segments/2` to fully replace the content an HL7 message.\n\n>","ref":"HL7.html"},{"type":"module","title":"Migrating from HL7.Message, HL7.Segment and HL7.Query - HL7","doc":"> To migrate from the deprecated `HL7.Message` struct, use `HL7.new!/2` and `HL7.Message.new/2` to transform from one\n> struct to the other while preserving associated metadata tags.\n>\n> You can use `chunk_by_lead_segment/3` to generate segment groups to update code that relies on `HL7.Query` groupings.\n>\n> Any operations to otherwise query or modify HL7 data should be possible using\n> the `get/2`, `put/3`, `update!/3` and `update/4` functions.\n>\n> If you encounter other issues with feature parity, please open an issue!\n\n>","ref":"HL7.html#module-migrating-from-hl7-message-hl7-segment-and-hl7-query"},{"type":"module","title":"String.Chars Protocol - HL7","doc":"> You can use the `to_string()` implementation of the `String.Chars` protocol to quickly render HL7 structs as text.","ref":"HL7.html#module-string-chars-protocol"},{"type":"function","title":"HL7.chunk_by_lead_segment/3","doc":"Creates a list of lists in which the specified `segment_name` is used to get the first segment map\nof each list. This function helps to do things like grouping `OBX` segments with their parent `OBR` segment.\n\nOptions:\n\n`keep_prefix_segments: true` will leave the first set of non-matching segments in the return value.","ref":"HL7.html#chunk_by_lead_segment/3"},{"type":"type","title":"HL7.file_type_hl7/0","doc":"","ref":"HL7.html#t:file_type_hl7/0"},{"type":"function","title":"HL7.format/2","doc":"Converts an `HL7` struct into its string representation.\nConvenience options will be added in the future.","ref":"HL7.html#format/2"},{"type":"function","title":"HL7.get/2","doc":"Finds data within an `HL7` struct, parsed segments or repetitions\nusing an `HL7.Path` struct (see `sigil_p/2`).\n\nSelecting data across multiple segments or repetitions with the wildcard `[*]` pattern\nwill return a list of results.\n\nRepetition data can be searched using a partial path containing ony the component and/or\nsubcomponent with a preceding period, e.g. `~p\".2.3\"`.\n\nSee the `sigil_p/2` docs and tests for more examples!","ref":"HL7.html#get/2"},{"type":"function","title":"Examples - HL7.get/2","doc":"iex> import HL7, only: :sigils\n    iex> HL7.Examples.wikipedia_sample_hl7()\n    ...> |> HL7.new!()\n    ...> |> HL7.get(~p\"OBX-5\")\n    \"1.80\"\n\n    iex> import HL7, only: :sigils\n    iex> HL7.Examples.wikipedia_sample_hl7()\n    ...> |> HL7.new!()\n    ...> |> HL7.get(~p\"OBX[*]-5\")\n    [\"1.80\", \"79\"]\n\n    iex> import HL7, only: :sigils\n    iex> HL7.Examples.wikipedia_sample_hl7()\n    ...> |> HL7.new!()\n    ...> |> HL7.get(~p\"OBX[*]-2!\")\n    [\"N\", \"NM\"]\n\n    iex> import HL7, only: :sigils\n    iex> HL7.Examples.wikipedia_sample_hl7()\n    ...> |> HL7.new!()\n    ...> |> HL7.get(~p\"PID-11[*].5\")\n    [\"35209\", \"35200\"]\n\n    iex> import HL7, only: :sigils\n    iex> HL7.Examples.wikipedia_sample_hl7()\n    ...> |> HL7.new!()\n    ...> |> HL7.get(~p\"PID-11[2].1\")\n    \"NICKELL’S PICKLES\"\n\n    iex> import HL7\n    iex> HL7.Examples.wikipedia_sample_hl7()\n    ...> |> new!()\n    ...> |> get(~p\"PID\")\n    ...> |> get(~p\"11[*]\")\n    ...> |> get(~p\".1\")\n    [\"260 GOODWIN CREST DRIVE\", \"NICKELL’S PICKLES\"]\n\n    iex> import HL7\n    iex> HL7.Examples.wikipedia_sample_hl7() |> new!() |> get(~p\"OBX[*]\")\n    [\n      %{\n        0 => \"OBX\",\n        1 => \"1\",\n        2 => %{1 => %{1 => \"N\", 2 => %{1 => \"K\", 2 => \"M\"}}},\n        3 => %{1 => %{2 => \"Body Height\"}},\n        5 => \"1.80\",\n        6 => %{1 => %{1 => \"m\", 2 => \"Meter\", 3 => \"ISO+\"}},\n        11 => \"F\"\n      },\n      %{\n        0 => \"OBX\",\n        1 => \"2\",\n        2 => \"NM\",\n        3 => %{1 => %{2 => \"Body Weight\"}},\n        5 => \"79\",\n        6 => %{1 => %{1 => \"kg\", 2 => \"Kilogram\", 3 => \"ISO+\"}},\n        11 => \"F\"\n      }\n    ]","ref":"HL7.html#get/2-examples"},{"type":"function","title":"HL7.get_segments/1","doc":"Returns a list of sparse maps (with ordinal indices and strings) representing\nthe parsed segments of an HL7 message stored in an `HL7` struct.","ref":"HL7.html#get_segments/1"},{"type":"function","title":"HL7.get_tags/1","doc":"Returns a map of custom metadata associated with the `HL7` struct.","ref":"HL7.html#get_tags/1"},{"type":"type","title":"HL7.hl7_list_data/0","doc":"","ref":"HL7.html#t:hl7_list_data/0"},{"type":"type","title":"HL7.hl7_map_data/0","doc":"","ref":"HL7.html#t:hl7_map_data/0"},{"type":"function","title":"HL7.label/2","doc":"Labels source data (a segment map or list of segment maps) by using `HL7.Path`s in a labeled\noutput template.\n\nOne-arity functions placed as output template values will be called with the source data.","ref":"HL7.html#label/2"},{"type":"function","title":"Examples - HL7.label/2","doc":"iex> import HL7, only: :sigils\n    iex> HL7.Examples.wikipedia_sample_hl7()\n    ...> |> HL7.new!()\n    ...> |> HL7.label(%{mrn: ~p\"PID-3!\", name: ~p\"PID-5.2\"})\n    %{mrn: \"56782445\", name: \"BARRY\"}","ref":"HL7.html#label/2-examples"},{"type":"function","title":"HL7.new/2","doc":"Creates an HL7 struct from valid HL7 data (accepting text, lists or the deprecated `HL7.Message` struct).\nReturns `{:ok, HL7.t()}` if successful, `{:error, HL7.InvalidMessage.t()}` otherwise.","ref":"HL7.html#new/2"},{"type":"function","title":"HL7.new!/2","doc":"Creates an HL7 struct from valid HL7 data (accepting text, lists or the deprecated `HL7.Message` struct).\nRaises with a `RuntimeError` if the data is not valid HL7.","ref":"HL7.html#new!/2"},{"type":"function","title":"Examples - HL7.new!/2","doc":"iex> import HL7\n    iex> HL7.Examples.wikipedia_sample_hl7() |> new!()\n    #HL7","ref":"HL7.html#new!/2-examples"},{"type":"function","title":"HL7.new_segment/1","doc":"Creates a minimal map representing an empty HL7 segment that can\nbe modified via this module.","ref":"HL7.html#new_segment/1"},{"type":"function","title":"HL7.open_hl7_file_stream/2","doc":"Opens an HL7 file stream of either `:mllp` or `:line`. If the file_type is not specified\nit will be inferred from the first three characters of the file contents.","ref":"HL7.html#open_hl7_file_stream/2"},{"type":"type","title":"HL7.parsed_hl7/0","doc":"","ref":"HL7.html#t:parsed_hl7/0"},{"type":"function","title":"HL7.put/3","doc":"Puts data within an `HL7` struct, parsed segments or repetitions\nusing an `HL7.Path` struct (see `sigil_p/2`).","ref":"HL7.html#put/3"},{"type":"function","title":"Examples - HL7.put/3","doc":"Put field data as a string.\n\n    iex> import HL7\n    iex> HL7.Examples.wikipedia_sample_hl7()\n    ...> |> new!()\n    ...> |> put(~p\"PID-8\", \"F\")\n    ...> |> get(~p\"PID-8\")\n    \"F\"\n\n\nPut field data as a string overwriting all repetitions.\n\n    iex> import HL7\n    iex> HL7.Examples.wikipedia_sample_hl7()\n    ...> |> new!()\n    ...> |> put(~p\"PID-11[*]\", \"SOME_ID\")\n    ...> |> get(~p\"PID-11[*]\")\n    [\"SOME_ID\"]\n\nPut field data into a single repetition.\n\n    iex> import HL7\n    iex> HL7.Examples.wikipedia_sample_hl7()\n    ...> |> new!()\n    ...> |> put(~p\"PID-3[2]\", [\"a\", \"b\", \"c\"])\n    ...> |> get(~p\"PID-3[2].3\")\n    \"c\"\n\nPut component data across multiple repetitions.\n\n    iex> import HL7\n    iex> HL7.Examples.wikipedia_sample_hl7()\n    ...> |> new!()\n    ...> |> put(~p\"PID-11[*].3\", \"SOME_PLACE\")\n    ...> |> get(~p\"PID-11[*].3\")\n    [\"SOME_PLACE\", \"SOME_PLACE\"]\n\nPut data in a segment using just the path to a field.\n\n    iex> import HL7\n    iex> HL7.Examples.wikipedia_sample_hl7()\n    ...> |> new!()\n    ...> |> get(~p\"PID\")\n    ...> |> put(~p\"3\", \"SOME_ID\")\n    ...> |> get(~p\"3\")\n    \"SOME_ID\"\n\nPut data across multiple segments\n\n    iex> import HL7\n    iex> HL7.Examples.wikipedia_sample_hl7()\n    ...> |> new!()\n    ...> |> put(~p\"OBX[*]-5\", \"REDACTED\")\n    ...> |> get(~p\"OBX[*]-5\")\n    [\"REDACTED\", \"REDACTED\"]","ref":"HL7.html#put/3-examples"},{"type":"type","title":"HL7.segment/0","doc":"","ref":"HL7.html#t:segment/0"},{"type":"function","title":"HL7.set_segments/2","doc":"Sets a list of sparse maps (with ordinal indices and strings) representing\nthe parsed segments of an HL7 message to define the content of an `HL7` struct.","ref":"HL7.html#set_segments/2"},{"type":"function","title":"HL7.set_tags/2","doc":"Sets a map of custom metadata associated with the `HL7` struct.","ref":"HL7.html#set_tags/2"},{"type":"macro","title":"HL7.sigil_p/2","doc":"The `~p` sigil encodes an HL7 path into a struct at compile-time to guarantee correctness and speed.\nIt is designed to work with data returned by `HL7.new!/1`, providing a standard way to get and update\nHL7 message content.\n\n>","ref":"HL7.html#sigil_p/2"},{"type":"macro","title":"Importing Just the Sigil - HL7.sigil_p/2","doc":"> Use `import HL7, only: :sigils` to access the `~p` sigil without importing the other `HL7` functions.\n\nThe full path structure in HL7 is expressed as:\n\n`~p\"SEGMENT_NAME[SEGMENT_NUMBER]-FIELD[REPETITION].COMPONENT.SUBCOMPONENT`\n\nA trailing exclamation mark can be used in the path to the return only the leftmost text at the given level.\n\nPosition Name | Valid Values\n------------ | -------------\n`SEGMENT_NAME` | 3 character string\n`SEGMENT_NUMBER` | Positive integer in square brackets, defaults to 1. All segments of `SEGMENT_NAME` can be accessed with `[*]`\n`FIELD` | Positive integer\n`REPETITION` | Positive integer in square brackets, defaults to 1. All repetitions of the `FIELD` can be accessed with `[*]`\n`COMPONENT` | Positive integer\n`SUBCOMPONENT` | Positive integer\n\n>","ref":"HL7.html#sigil_p/2-importing-just-the-sigil"},{"type":"macro","title":"1-based Indexes - HL7.sigil_p/2","doc":"> To match industry expectations, HL7 uses 1-based indexes.\n> As noted above, it also includes defaults whereby all paths refer to the 1st segment and/or 1st repetition\n> of any query unless explicitly specified.\n\nExample paths:\n\n   HL7 Path | Description\n`~p\"OBX\"` | The 1st OBX segment in its entirety, the same as `~p\"OBX[1]\"`.\n`~p\"OBX-5\"` | The 1st repetition of the 5th field of the 1st OBX segment.\n`~p\"OBX[1]-5[1]\"` | Same as above. The numbers in brackets specify the default repetition and segment number values.\n`~p\"OBX-5[*]\"` | Every repetition of the 5th field of the 1st OBX segment, returning a list of results.\n`~p\"OBX[2]-5\"` | The 1st repetition of the 5th field of the 2nd OBX segment.\n`~p\"OBX[*]-5\"` | The 1st repetition of the 5th field of every OBX segment, returning a list of results.\n`~p\"OBX[*]-5[*]\"` | Every repetition of the 5th field of every OBX segment, returning a nested list of results.\n`~p\"OBX-5.2\"` | The 2nd component of the 1st repetition of the 5th field of the 1st OBX segment.\n`~p\"OBX-5.2.3\"` | The 3rd subcomponent of the 2nd component of the 1st repetition of the 5th field of the 1st OBX segment.\n`~p\"OBX[*]-5.2.3\"` | Same as above, but returned as a list with a value for each OBX segment.\n`~p\"OBX[*]-5[*].2.3\"` | Same as above, but now a nested list of results for each repetition within each segment.\n`~p\"OBX-5!\"` | The `!` will take the first text (leftmost value) at whatever level is specified. Thus, `p\"OBX-5!\"` is equivalent to `p\"OBX-5.1.1\"`.\n`~p\"5\"` | The fifth field of a segment (parsed as an ordinal map starting with 0)\n`~p\".2\"` | The second component of a repetition (parsed as an ordinal map starting with 1)\n\nNote that repetitions are uncommon in HL7 and the default of a 1st repetition is often just assumed.\n`~p\"PID-3\"` is equivalent to `~p\"PID-3[1]\"` and is the most standard representation.\n\nAll repetitions can be found using a repetition wildcard: `~p\"PID-11[*]\"`. A list of lists can\nbe produced by selecting multiple segments and multiple repetitions with `~p\"PID[*]-11[*]\"`.\n\nComponents and subcomponents can also be accessed with the path structures.\n`p\"OBX-2.3.1\"` would return the 1st subcomponent of the 3rd component of the 2nd field of the 1st OBX.\n\nIf dealing with segments or repetitions extracted from parsed HL7, you can use partial paths that\nlack the segment name and/or field like `~p\"5\"` for the fifth field of a segment or `~p\".3\"` for the 3rd\ncomponent of a repetition.\n\nAdditionally, if a path might have additional data such that a string might be found at either\n`~p\"OBX-2\"` or `~p\"OBX-2.1\"` or even `~p\"OBX-2.1.1\"`, there is truncation character (`!`) that\nwill return the first element found in the HL7 text at the target specificity. Thus, `~p\"OBX[*]-2!\"`\nwould get the 1st piece of data in the 2nd field of every OBX whether it is a string or nested map.\n\n>","ref":"HL7.html#sigil_p/2-1-based-indexes"},{"type":"macro","title":"Nil vs Empty String - HL7.sigil_p/2","doc":"> Paths that query beyond the content of an HL7 document, e.g. asking for the 10th field of a segment with five fields,\n> will return `nil` as opposed to an empty string to indicate that the data does not exist. Adding the\n> trailing `!` to an `HL7.Path` will force all return values to be simple strings in cases where `nil` is not desired.\n> Note that it also returns the leftmost text at the path level, discarding extra data as noted above.","ref":"HL7.html#sigil_p/2-nil-vs-empty-string"},{"type":"macro","title":"Examples - HL7.sigil_p/2","doc":"iex> import HL7, only: :sigils\n    iex> HL7.Examples.wikipedia_sample_hl7() |> HL7.new!() |> HL7.get(~p\"OBX-5\")\n    \"1.80\"\n\n    iex> import HL7\n    iex> HL7.Examples.wikipedia_sample_hl7() |> new!() |> get(~p\"OBX-3\")\n    %{2 => \"Body Height\"}\n\n    iex> import HL7\n    iex> HL7.Examples.wikipedia_sample_hl7() |> new!() |> get(~p\"PID-11!\")\n    \"260 GOODWIN CREST DRIVE\"\n\n    iex> import HL7\n    iex> HL7.Examples.wikipedia_sample_hl7() |> new!() |> get(~p\"OBX[*]-5\")\n    [\"1.80\", \"79\"]\n\n    iex> import HL7\n    iex> HL7.Examples.wikipedia_sample_hl7() |> new!() |> get(~p\"OBX[*]-2!\")\n    [\"N\", \"NM\"]\n\n    iex> import HL7\n    iex> HL7.Examples.wikipedia_sample_hl7() |> new!() |> get(~p\"PID-11[*].5\")\n    [\"35209\", \"35200\"]\n\n    iex> import HL7\n    iex> HL7.Examples.wikipedia_sample_hl7() |> new!() |> get(~p\"PID[*]-11[*].5\")\n    [[\"35209\", \"35200\"]]\n\n    iex> import HL7\n    iex> HL7.Examples.wikipedia_sample_hl7() |> new!() |> get(~p\"PID-11[2].1\")\n    \"NICKELL’S PICKLES\"\n\n    iex> import HL7\n    iex> HL7.Examples.wikipedia_sample_hl7()\n    ...> |> new!()\n    ...> |> get(~p\"PID-11[*]\")\n    ...> |> List.last()\n    ...> |> get(~p\".1\")\n    \"NICKELL’S PICKLES\"","ref":"HL7.html#sigil_p/2-examples"},{"type":"type","title":"HL7.t/0","doc":"","ref":"HL7.html#t:t/0"},{"type":"function","title":"HL7.to_list/1","doc":"Converts an HL7 message struct into a nested list of strings.","ref":"HL7.html#to_list/1"},{"type":"function","title":"HL7.update/4","doc":"Updates data within an `HL7` struct, parsed segments, or repetitions\nusing an `HL7.Path` struct (see `sigil_p/2`).","ref":"HL7.html#update/4"},{"type":"function","title":"HL7.update!/3","doc":"Updates data within an `HL7` struct, parsed segments, or repetitions\nusing an `HL7.Path` struct (see `sigil_p/2`). Raises a `RuntimeError`\nif the path is not present in the source data.","ref":"HL7.html#update!/3"},{"type":"module","title":"HL7.Examples","doc":"Functions to provide sample HL7 data which can be used to explore the API.","ref":"HL7.Examples.html"},{"type":"function","title":"HL7.Examples.elr_example/0","doc":"","ref":"HL7.Examples.html#elr_example/0"},{"type":"function","title":"HL7.Examples.nist_immunization_hl7/0","doc":"","ref":"HL7.Examples.html#nist_immunization_hl7/0"},{"type":"function","title":"HL7.Examples.nist_syndromic_hl7/0","doc":"","ref":"HL7.Examples.html#nist_syndromic_hl7/0"},{"type":"function","title":"HL7.Examples.wikipedia_sample_hl7/1","doc":"Returns a sample HL7 string from [Wikipedia's HL7 article](https://en.wikipedia.org/wiki/Health_Level_7#Version_2_messaging).\n\nThe HL7 version of the message defaults to 2.5, but can be overidden.","ref":"HL7.Examples.html#wikipedia_sample_hl7/1"},{"type":"function","title":"HL7.Examples.wikipedia_sample_hl7_alt_delimiters/0","doc":"","ref":"HL7.Examples.html#wikipedia_sample_hl7_alt_delimiters/0"},{"type":"module","title":"HL7.Header","doc":"An HL7 header implementation that can be used to build MSH segments and HL7 messages.\nIt is also exposed as metadata after parsing any HL7 message.","ref":"HL7.Header.html"},{"type":"function","title":"HL7.Header.get_message_date_time/0","doc":"","ref":"HL7.Header.html#get_message_date_time/0"},{"type":"function","title":"HL7.Header.get_message_type_field/1","doc":"","ref":"HL7.Header.html#get_message_type_field/1"},{"type":"function","title":"HL7.Header.new/5","doc":"","ref":"HL7.Header.html#new/5"},{"type":"type","title":"HL7.Header.t/0","doc":"","ref":"HL7.Header.html#t:t/0"},{"type":"function","title":"HL7.Header.to_msh/1","doc":"","ref":"HL7.Header.html#to_msh/1"},{"type":"module","title":"HL7.InvalidHeader","doc":"Contains information concerning any failed attempt to parse an HL7 MSH segment.","ref":"HL7.InvalidHeader.html"},{"type":"type","title":"HL7.InvalidHeader.t/0","doc":"","ref":"HL7.InvalidHeader.html#t:t/0"},{"type":"module","title":"HL7.Path","doc":"A module and struct representing an HL7 path. This is typically created through the `HL7.sigil_p/2` macro\nin order to gain compile-time correctness guarantees.","ref":"HL7.Path.html"},{"type":"function","title":"HL7.Path.new/1","doc":"Creates an HL7 path struct at runtime.","ref":"HL7.Path.html#new/1"},{"type":"function","title":"Examples - HL7.Path.new/1","doc":"iex> HL7.Examples.wikipedia_sample_hl7()\n    ...> |> HL7.new!()\n    ...> |> HL7.get(HL7.Path.new(\"OBX-5\"))\n    \"1.80\"","ref":"HL7.Path.html#new/1-examples"},{"type":"type","title":"HL7.Path.t/0","doc":"","ref":"HL7.Path.html#t:t/0"},{"type":"module","title":"HL7.FieldGrammar","doc":"Represents an HL7 path.","ref":"HL7.FieldGrammar.html"},{"type":"function","title":"HL7.FieldGrammar.to_indices/1","doc":"","ref":"HL7.FieldGrammar.html#to_indices/1"},{"type":"module","title":"HL7.InvalidMessage","doc":"Contains information concerning any failed attempt\nto parse an HL7 message, generally MSH-related","ref":"HL7.InvalidMessage.html"},{"type":"type","title":"HL7.InvalidMessage.t/0","doc":"","ref":"HL7.InvalidMessage.html#t:t/0"},{"type":"module","title":"HL7.Message","doc":"Creates, parses and modifies HL7 messages with a focus on performance. Contains a list of parsed segments and header metadata.\n\nUse `HL7.Message.new/2` to create an `t:HL7.Message.t/0` struct that contains a fully parsed HL7 message alongside header metadata.\nThe parsed data is represented as minimally as possible as lists of string and lists.\n\n\nThe second argument is an options map supporting the following values:\n\n`copy: true` -- Will create binary copies while parsing to avoid keeping references.\n\n`validate_string: true` -- Will generate an `HL7.InvalidMessage` if the source text is not UTF-8 compatible.","ref":"HL7.Message.html"},{"type":"type","title":"HL7.Message.content_hl7/0","doc":"","ref":"HL7.Message.html#t:content_hl7/0"},{"type":"function","title":"HL7.Message.find/2","doc":"Returns the first parsed segment matching `segment_name` from an HL7 message or content.","ref":"HL7.Message.html#find/2"},{"type":"type","title":"HL7.Message.fragment_hl7/0","doc":"","ref":"HL7.Message.html#t:fragment_hl7/0"},{"type":"function","title":"HL7.Message.new/2","doc":"Creates an `HL7.Message` struct containing parsed segment list data. It will\nalso expose basic header information (e.g. encoding characters, message type) for routing.\n\nPass `copy: true` as the second argument to generate binary copies of all substrings as it parses the message.\n\nInvalid MSH formats will return an `HL7.InvalidMessage`.","ref":"HL7.Message.html#new/2"},{"type":"function","title":"Examples - HL7.Message.new/2","doc":"iex> HL7.Examples.wikipedia_sample_hl7()\n    ...> |> HL7.Message.new()\n    ...> |> HL7.Query.get_segment_names()\n    [\"MSH\", \"EVN\", \"PID\", \"PV1\", \"OBX\", \"OBX\", \"AL1\", \"DG1\"]\n\n    iex> HL7.Message.new(\n    ...>   \"MSH|^~\\\\&|MegaReg|XYZHospC|SuperOE|XYZImgCtr|\" <>\n    ...>   \"20060529090131-0500||ADT^A01^ADT_A01|01052901|P|2.5\")\n    ...> |> HL7.Query.get_segment_names()\n    [\"MSH\"]\n\n    iex> HL7.Message.new(\n    ...>   [[\"MSH\", \"|\", \"^~\\\\&\", \"App\", \"Facility\", \"\", \"\",\n    ...>     \"20060529090131-0500\", \"\", [[\"ADT\", \"A01\", \"ADT_A01\"]],\n    ...>     \"01052901\", \"P\", \"2.5\"]])\n    ...> |> HL7.Query.get_segment_names()\n    [\"MSH\"]","ref":"HL7.Message.html#new/2-examples"},{"type":"type","title":"HL7.Message.parsed_hl7/0","doc":"","ref":"HL7.Message.html#t:parsed_hl7/0"},{"type":"function","title":"HL7.Message.raw/1","doc":"Creates an `HL7.Message` struct containing the raw HL7 text for further processing. It will\nalso expose basic header information (e.g. encoding characters, message type) for routing.\n\nInvalid MSH formats will return an `HL7.InvalidMessage` struct.","ref":"HL7.Message.html#raw/1"},{"type":"type","title":"HL7.Message.raw_hl7/0","doc":"","ref":"HL7.Message.html#t:raw_hl7/0"},{"type":"type","title":"HL7.Message.segment_hl7/0","doc":"","ref":"HL7.Message.html#t:segment_hl7/0"},{"type":"type","title":"HL7.Message.t/0","doc":"","ref":"HL7.Message.html#t:t/0"},{"type":"function","title":"HL7.Message.to_list/1","doc":"Returns a parsed list of segments from an HL7 message or content.","ref":"HL7.Message.html#to_list/1"},{"type":"module","title":"HL7.Query","doc":"Queries and modifies HL7 messages using Field and Segment Grammar Notations with a pipeline-friendly API and set-based\noperations.\n\nSimilar to libraries such as jQuery and D3, `HL7.Query` is designed around the concept of selecting and sub-selecting\nelements (segments or segment groups) in an HL7 message. The full message context is retained in the `HL7.Query`\nstruct so that messages can be modified piecemeal and then reconstructed as strings.\n\nIn general, use `HL7.Query.select/2` with a segment selector (similar to CSS selectors) to select lists of segment groups.\n\nThe segment selector is written as a string of ordered segment names. Curly braces surround repeating elements.\nSquare brackets enclose optional elements. These can be nested to create selectors that can select complex groups of segments or validate\nentire HL7 message layouts.\n\nFor example, an ORU_R01 HL7 message's Order Group selector could be written as:\n\n`\"[ORC] OBR {[NTE]} {[OBX {[NTE]}]}\"`.\n\nNote that this would look for OBRs, optionally preceded by an ORC, possibly followed by one or more NTEs, maybe followed\nagain by one or more OBRs with their own optional NTE sets.\n\nTo reference data within segments, there is a field selector format that can access fields, repetitions, components\nand sub-components across one or more segments. All indices start at one, and the repetition index defaults to one\nunless specified within brackets after the field number.\n\nField Selector | Description\n------------ | -------------\n`\"PID-11[2].4\"` | PID segments, 11th field, 2nd repetition, 4th component\n`\"OBX-2.2.1\"` | OBX segments, 2nd field, 2nd component, 1st sub-component\n`\"1\"` | All segments, 1st field\n`\"3[4].2\"` | All segments, 3rd field, 4th repetition, 2nd component","ref":"HL7.Query.html"},{"type":"function","title":"HL7.Query.append/2","doc":"Appends a segment or segments to the currently _selected_ segments in each selection.","ref":"HL7.Query.html#append/2"},{"type":"type","title":"HL7.Query.content_hl7/0","doc":"","ref":"HL7.Query.html#t:content_hl7/0"},{"type":"type","title":"HL7.Query.content_or_query_hl7/0","doc":"","ref":"HL7.Query.html#t:content_or_query_hl7/0"},{"type":"function","title":"HL7.Query.count/1","doc":"Returns the current selection count.","ref":"HL7.Query.html#count/1"},{"type":"function","title":"HL7.Query.data/2","doc":"Associates data with each selection. This data remains accessible to\nchild selections.\n\nEach selection stores a map of data. The supplied `fun` should\naccept an `HL7.Query` and return a map of key-values to be merged into the\nexisting map of data.\n\nSelections automatically include the index of the current selection, i.e., `%{index: 5}`.\nFor HL7 numbering, the index values begin at 1.","ref":"HL7.Query.html#data/2"},{"type":"function","title":"Examples - HL7.Query.data/2","doc":"iex> import HL7.Query\n    iex> HL7.Examples.nist_immunization_hl7()\n    ...> |> select(\"ORC RXA RXR {[OBX]}\")\n    ...> |> data(fn q -> %{order_num: find_first(q, ~p\"ORC-3.1\")} end)\n    ...> |> select(\"OBX\")\n    ...> |> update(~p\"6\", fn q -> get_datum(q, :order_num) end)\n    ...> |> root()\n    ...> |> find_first(~p\"OBX-6\")\n    \"IZ-783278\"\n\n    iex> import HL7.Query\n    iex> HL7.Examples.nist_immunization_hl7()\n    ...> |> select(\"ORC RXA RXR {[OBX]}\")\n    ...> |> data(fn q -> %{group_num: get_index(q)} end)\n    ...> |> select(\"OBX\")\n    ...> |> update(~p\"6\", fn q -> get_datum(q, :group_num) end)\n    ...> |> root()\n    ...> |> find_all(~p\"OBX-6\")\n    [1, 1, 1, 1, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2]","ref":"HL7.Query.html#data/2-examples"},{"type":"function","title":"HL7.Query.delete/1","doc":"Deletes all selections in the query document.","ref":"HL7.Query.html#delete/1"},{"type":"function","title":"HL7.Query.filter/2","doc":"Filters (deletes) segments within selections by whitelisting one or more segment types.\nAccepts either a segment name, list of acceptable names, or a function that takes an `HL7.Query`\n(containing one sub-selected segment at a time) and returns a boolean filter value.","ref":"HL7.Query.html#filter/2"},{"type":"function","title":"Examples - HL7.Query.filter/2","doc":"iex> import HL7.Query\n    iex> HL7.Examples.nist_immunization_hl7()\n    ...> |> filter([\"MSH\", \"PID\", \"ORC\"])\n    ...> |> root()\n    ...> |> get_segment_names()\n    [\"MSH\", \"PID\", \"ORC\", \"ORC\", \"ORC\"]","ref":"HL7.Query.html#filter/2-examples"},{"type":"function","title":"HL7.Query.find_all/2","doc":"Returns a flattened list of segment parts from _selected_ segments across all selections using\nthe given `field_selector`.\n\n`PID-3[2].1.2` PID segments, field 3, repetition 2, component 1, subcomponent 2\n\n`OBX-5` OBX segments, field 5\n\n`2.3` All segments, field 2, component 3","ref":"HL7.Query.html#find_all/2"},{"type":"function","title":"HL7.Query.find_first/2","doc":"Returns a segment part from the first _selected_ segment (of the given name, if specified)\nacross all selections using the given `field_selector`.\n\n`PID-3[2].1.2` PID segments, field 3, repetition 2, component 1, subcomponent 2\n\n`OBX-5` OBX segments, field 5\n\n`2.3` All segments, field 2, component 3","ref":"HL7.Query.html#find_first/2"},{"type":"function","title":"HL7.Query.get_data/1","doc":"Returns a list containing an associated data map for each selection in the given `HL7.Query`.","ref":"HL7.Query.html#get_data/1"},{"type":"function","title":"HL7.Query.get_datum/3","doc":"Returns the associated key-value of the first (or only) selection for the given `HL7.Query`.","ref":"HL7.Query.html#get_datum/3"},{"type":"function","title":"HL7.Query.get_index/1","doc":"Returns the selection index of the first (or only) selection for the given `HL7.Query`.","ref":"HL7.Query.html#get_index/1"},{"type":"function","title":"Examples - HL7.Query.get_index/1","doc":"iex> import HL7.Query\n    iex> HL7.Examples.nist_immunization_hl7()\n    ...> |> select(\"ORC RXA RXR {[OBX]}\")\n    ...> |> map(fn q -> get_index(q) end)\n    [1, 2]\n\n    iex> import HL7.Query\n    iex> HL7.Examples.nist_immunization_hl7()\n    ...> |> select(\"ORC RXA RXR {[OBX]}\")\n    ...> |> select(\"OBX\")\n    ...> |> map(fn q -> get_index(q) end)\n    [1, 2, 3, 4, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10]\n\n    iex> import HL7.Query\n    iex> HL7.Examples.nist_immunization_hl7()\n    ...> |> select(\"OBX\")\n    ...> |> map(fn q -> get_index(q) end)\n    [1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14]","ref":"HL7.Query.html#get_index/1-examples"},{"type":"function","title":"HL7.Query.get_part/2","doc":"","ref":"HL7.Query.html#get_part/2"},{"type":"function","title":"HL7.Query.get_parts/2","doc":"","ref":"HL7.Query.html#get_parts/2"},{"type":"function","title":"HL7.Query.get_segment_groups/1","doc":"Returns a list containing a list of _selected_ segments for each selection.","ref":"HL7.Query.html#get_segment_groups/1"},{"type":"function","title":"HL7.Query.get_segment_names/1","doc":"Returns a flattened list of segment names across all selections.","ref":"HL7.Query.html#get_segment_names/1"},{"type":"function","title":"HL7.Query.get_segments/1","doc":"Returns a flattened list of _selected_ segments across all selections.","ref":"HL7.Query.html#get_segments/1"},{"type":"function","title":"HL7.Query.map/2","doc":"Maps across each selection with a `fun` that accepts an `HL7.Query`\n(handling one selection at a time) and returns a results list.","ref":"HL7.Query.html#map/2"},{"type":"function","title":"Examples - HL7.Query.map/2","doc":"iex> import HL7.Query\n    iex> HL7.Examples.nist_immunization_hl7()\n    ...> |> select(\"RXA\")\n    ...> |> map(fn q -> find_first(q, ~p\"5.2\") end)\n    [\"Influenza\", \"PCV 13\", \"DTaP-Hep B-IPV\"]","ref":"HL7.Query.html#map/2-examples"},{"type":"function","title":"HL7.Query.new/1","doc":"Creates an `HL7.Query` struct that selects an entire HL7 Message. This step is implicitly carried out by most other\nfunctions in this module. As it involves parsing an HL7 message, one should\ncache this result if invoked repeatedly.","ref":"HL7.Query.html#new/1"},{"type":"function","title":"HL7.Query.number_set_ids/1","doc":"Updates the set numbers in each segment's first field to be their respective selection indices.","ref":"HL7.Query.html#number_set_ids/1"},{"type":"type","title":"HL7.Query.parsed_hl7/0","doc":"","ref":"HL7.Query.html#t:parsed_hl7/0"},{"type":"type","title":"HL7.Query.parsed_or_query_hl7/0","doc":"","ref":"HL7.Query.html#t:parsed_or_query_hl7/0"},{"type":"function","title":"HL7.Query.prepend/2","doc":"Prepends a segment or list of segments to the segments in each of the current selections.","ref":"HL7.Query.html#prepend/2"},{"type":"type","title":"HL7.Query.raw_hl7/0","doc":"","ref":"HL7.Query.html#t:raw_hl7/0"},{"type":"function","title":"HL7.Query.reject/2","doc":"Rejects (deletes) segments within selections by blacklisting one or more segment types.\nAccepts either a segment name, list of acceptable names, or a function that takes an `HL7.Query`\n(containing one sub-selected segment at a time) and returns a boolean reject value.","ref":"HL7.Query.html#reject/2"},{"type":"function","title":"Examples - HL7.Query.reject/2","doc":"iex> import HL7.Query\n    iex> HL7.Examples.nist_immunization_hl7()\n    ...> |> reject([\"OBX\", \"RXA\", \"RXR\"])\n    ...> |> root()\n    ...> |> get_segment_names()\n    [\"MSH\", \"PID\", \"ORC\", \"ORC\", \"ORC\"]","ref":"HL7.Query.html#reject/2-examples"},{"type":"function","title":"HL7.Query.reject_z_segments/1","doc":"Rejects (deletes) Z-segments in all selections.","ref":"HL7.Query.html#reject_z_segments/1"},{"type":"function","title":"HL7.Query.replace/2","doc":"Replaces all segments in each selection. The given `fun` should\naccept an `HL7.Query` (referencing a single selection) and return a list of replacement segments\n(in parsed list format).","ref":"HL7.Query.html#replace/2"},{"type":"function","title":"HL7.Query.replace_parts/3","doc":"","ref":"HL7.Query.html#replace_parts/3"},{"type":"function","title":"HL7.Query.root/1","doc":"Selects the entire an `HL7.Query` into an `HL7.Message`.","ref":"HL7.Query.html#root/1"},{"type":"function","title":"HL7.Query.select/2","doc":"Selects or sub-selects segment groups in an HL7 message using a segment selector or filter function.\n\n    iex> import HL7.Query\n    iex> HL7.Examples.nist_immunization_hl7()\n    ...> |> select(\"OBX\")\n    ...> |> select(fn q -> find_first(q, ~p\"1\") != \"1\" end)\n    ...> |> delete()\n    ...> |> root()\n    ...> |> get_segment_names()\n    [\"MSH\", \"PID\", \"ORC\", \"RXA\", \"RXR\", \"OBX\", \"ORC\", \"RXA\", \"ORC\", \"RXA\", \"RXR\", \"OBX\"]","ref":"HL7.Query.html#select/2"},{"type":"macro","title":"HL7.Query.sigil_g/2","doc":"","ref":"HL7.Query.html#sigil_g/2"},{"type":"macro","title":"HL7.Query.sigil_p/2","doc":"Checks the format of an hl7 path at compile time and returns an Path","ref":"HL7.Query.html#sigil_p/2"},{"type":"type","title":"HL7.Query.t/0","doc":"","ref":"HL7.Query.html#t:t/0"},{"type":"function","title":"HL7.Query.to_console/1","doc":"Outputs an ANSI representation of an `HL7.Query` with corresponding selection indices on the left.","ref":"HL7.Query.html#to_console/1"},{"type":"function","title":"HL7.Query.to_message/1","doc":"Converts an `HL7.Query` into an `HL7.Message`.","ref":"HL7.Query.html#to_message/1"},{"type":"function","title":"HL7.Query.update/3","doc":"Updates segment parts of all selected segments, iterating through each selection.\nA replacement function accepts an `HL7.Query` containing one selection with its\n`part` property set to the value found using the `field_selector`.","ref":"HL7.Query.html#update/3"},{"type":"function","title":"Examples - HL7.Query.update/3","doc":"iex> import HL7.Query\n    iex> HL7.Examples.nist_immunization_hl7()\n    ...> |> update(~p\"OBX-3.2\", fn q -> \"TEST: \" <> q.part end)\n    ...> |> find_all(~p\"OBX-3.2\")\n    ...> |> List.first()\n    \"TEST: Vaccine funding program eligibility category\"\n\n    iex> import HL7.Query\n    iex> HL7.Examples.wikipedia_sample_hl7()\n    ...> |> select(\"PID\")\n    ...> |> update(~p\"5.2\", \"UNKNOWN\")\n    ...> |> find_first(~p\"PID-5.2\")\n    \"UNKNOWN\"","ref":"HL7.Query.html#update/3-examples"},{"type":"module","title":"HL7.RawMessage","doc":"Contains the raw text of an HL7 message alongside parsed header metadata from the MSH segment.\n\nUse `HL7.Message.raw/1` to generate the `t:HL7.RawMessage.t/0` struct","ref":"HL7.RawMessage.html"},{"type":"type","title":"HL7.RawMessage.t/0","doc":"","ref":"HL7.RawMessage.html#t:t/0"},{"type":"module","title":"HL7.Segment","doc":"Filter, parse and modify individual HL7 segments and their fragments.","ref":"HL7.Segment.html"},{"type":"type","title":"HL7.Segment.content_hl7/0","doc":"","ref":"HL7.Segment.html#t:content_hl7/0"},{"type":"type","title":"HL7.Segment.fragment_hl7/0","doc":"","ref":"HL7.Segment.html#t:fragment_hl7/0"},{"type":"function","title":"HL7.Segment.get_part/5","doc":"Extracts content from a parsed HL7 segment,\nreturning nested data by applying each supplied index in turn. Please note that HL7 indices start at 1.","ref":"HL7.Segment.html#get_part/5"},{"type":"function","title":"HL7.Segment.leftmost_value/1","doc":"","ref":"HL7.Segment.html#leftmost_value/1"},{"type":"type","title":"HL7.Segment.parsed_hl7/0","doc":"","ref":"HL7.Segment.html#t:parsed_hl7/0"},{"type":"type","title":"HL7.Segment.raw_hl7/0","doc":"","ref":"HL7.Segment.html#t:raw_hl7/0"},{"type":"function","title":"HL7.Segment.replace_part/6","doc":"Updates content within a parsed HL7 segment, returning a modified segment whose data has been transformed at the given\nindices (starting at 1 as with HL7's convention). The `transform` can be either a `string`, `list` or `fn old_data -> new_data`.","ref":"HL7.Segment.html#replace_part/6"},{"type":"type","title":"HL7.Segment.segment_hl7/0","doc":"","ref":"HL7.Segment.html#t:segment_hl7/0"},{"type":"module","title":"HL7.Separators","doc":"Contains HL7 delimiter information (optionally specified by the end system) used to parse or generate HL7 messages.","ref":"HL7.Separators.html"},{"type":"function","title":"HL7.Separators.new/1","doc":"","ref":"HL7.Separators.html#new/1"},{"type":"function","title":"HL7.Separators.new/2","doc":"","ref":"HL7.Separators.html#new/2"},{"type":"type","title":"HL7.Separators.t/0","doc":"","ref":"HL7.Separators.html#t:t/0"},{"type":"extras","title":"Elixir HL7","doc":"# Elixir HL7 \n\n[![hex.pm version](https://img.shields.io/hexpm/v/elixir_hl7.svg)](https://hex.pm/packages/elixir_hl7) \n[![hex.pm downloads](https://img.shields.io/hexpm/dt/elixir_hl7.svg)](https://hex.pm/packages/elixir_hl7)\n[![hex.pm license](https://img.shields.io/hexpm/l/elixir_hl7.svg)](https://hex.pm/packages/elixir_hl7)\n\nAn Elixir library for working with HL7 v2.x healthcare data. \n\nElixir HL7 provides functions to parse, query and modify healthcare data that conforms to the HL7 v2.x standards. \nIt should be able to reconstruct any HL7 message without data loss or corruption.\n\nIt also provides basic support for reading HL7 file streams with configurable delimiters (MLLP included). \n\nThis library has been tested on a wide variety of real-world HL7 messages to ensure correctness and flexibility. \n\nSince many HL7 messages do not strictly conform to the standards specified for each version, the library does not\nattempt to enforce limits such as character counts or structural expectations. \n\nIn fact, HL7 uses implicit hierarchies within segments (by leaving out certain separators) and to group segments\n(via expected patterns only known to the consuming application).\n\nThe majority of the API currently resides in the eponymous `HL7` module.\n\nYou can learn more about HL7 here:\n* Wikipedia's [HL7 article](https://en.wikipedia.org/wiki/Health_Level_7)\n* The official HL7 website ([hl7.org](http://www.hl7.org/index.cfm))\n\nPlease [report an issue](https://github.com/HCA-Healthcare/elixir-hl7/issues) if something appears to be handled incorrectly.\n\n>","ref":"main.html"},{"type":"extras","title":"New HL7 API - Elixir HL7","doc":">\n> The new `HL7` module API replaces the `HL7.Query`, `HL7.Segment`, and `HL7.Message` modules. \n> \n> These will likely not be removed for some time, and their\n> removal will coincide with a major version release. \n> \n> For now, the two systems can exchange data when needed.\n> See [here](./HL7.html##module-migrating-from-hl7-message-hl7-segment-and-hl7-query) for details!","ref":"main.html#new-hl7-api"},{"type":"extras","title":"History - Elixir HL7","doc":"We originally downloaded the HL7 specifications and generated structs to represent all possible message variants.\nUnfortunately, thousands of vendors and hospitals do NOT actually follow these specifications. \nIt turned out to be a fool's errand.\n\nWe then created a library designed to loosely parse and manipulate HL7 documents. This worked quite well, but as\nit took inspiration from jQuery and D3js, it did not mesh well with canonical Elixir. \n\nThis is the third approach to this library. We've attempted to hew closely to the HL7 business domain terminology\nwhile also simplifying the API such that its data structures are more compatible with core Elixir modules like Map and Enum.","ref":"main.html#history"},{"type":"extras","title":"Installation - Elixir HL7","doc":"Add this library to your mix.exs file.\n\n```elixir\ndefp deps do\n  [{:elixir_hl7, \"~> 0.10.0\"}]\nend\n```","ref":"main.html#installation"},{"type":"extras","title":"Examples - Elixir HL7","doc":"The `HL7.Examples` module contains functions with sample data that you can use to explore the API.\n\n    iex> import HL7, only: :sigils\n    iex> HL7.Examples.wikipedia_sample_hl7()\n    ...> |> HL7.new!()\n    ...> |> HL7.get(~p\"MSH-9.1\")\n    \"ADT\"","ref":"main.html#examples"},{"type":"extras","title":"Parse - Elixir HL7","doc":"HL7 messages can be fully parsed into lists of sparse maps and strings to provide a compact representation \nof the underlying message structure.\n\nUse `HL7.new!/2` to parse raw HL7 into a struct and `HL7.get_segments/1` to view the parsed data.\n\n    iex> HL7.Examples.wikipedia_sample_hl7()\n    ...> |> HL7.new!()\n    ...> |> HL7.get_segments()\n    ...> |> Enum.at(1)\n    %{0 => \"EVN\", 2 => \"200605290901\", 6 => \"200605290900\"}","ref":"main.html#parse"},{"type":"extras","title":"Query - Elixir HL7","doc":"Use `HL7.get/2` with the `HL7.Path` struct (created using `HL7.sigil_p/2`) to query HL7 data.\n\n    iex> import HL7, only: :sigils\n    iex> HL7.Examples.nist_immunization_hl7()\n    ...> |> HL7.new!()\n    ...> |> HL7.get(~p\"RXA-5.2\")\n    \"Influenza\"","ref":"main.html#query"},{"type":"extras","title":"Modify - Elixir HL7","doc":"Modify the data within messages, segments or repetitions using `HL7.put/3` and `HL7.update/4`.\nUse the `HL7.Path` struct (created using `HL7.sigil_p/2`) to specify what to change.\n\n    iex> HL7.Examples.wikipedia_sample_hl7()\n    ...> |> HL7.new!()\n    ...> |> HL7.put(~p\"OBX[2]-5\", \"44\")\n    ...> |> HL7.get(~p\"OBX[*]-5\")\n    [\"1.80\", \"44\"]","ref":"main.html#modify"},{"type":"extras","title":"Create - Elixir HL7","doc":"Use `HL7.new/2`, `HL7.new_segment/1` and `HL7.set_segments/2` to build HL7 messages from scratch.\nNote: This API is currently being developed and extended.","ref":"main.html#create"},{"type":"extras","title":"Files - Elixir HL7","doc":"The `HL7` module contains utility functions to open file streams of HL7 message content with support for MLLP and standard `:line` storage. \nOther formats are somewhat supported by specifying expected prefix and suffix delimiters between messages.","ref":"main.html#files"},{"type":"extras","title":"Networking - Elixir HL7","doc":"A separate library, Elixir-MLLP, exists to manage MLLP connections. MLLP is a simple protocol on top of TCP that is commonly used for sending and receiving HL7 messages. \n\n# License\n\nElixir HL7 source code is released under Apache 2 License. Check the LICENSE file for more information.","ref":"main.html#networking"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.38.2"}}